#!/bin/bash

echo -e "\nTransfer U-Boot & Linux to target device\n"

[ $# -lt 1 ] && echo "Please input target device, e.g. ./mksd-linux.sh /dev/mmcblk0" && exit 1
[ ! -e $1 ] && echo "Device $1 not found" && exit 1
[ "`cat /sys/block/${1##*/}/device/type`" == "SD" ] && echo "Device $1 is type of SD." && exit 1

echo "All data on "$1" now will be destroyed! Continue? [y/n]"
read ans
if [ $ans != 'y' ]; then exit 1; fi

echo 0 > /proc/sys/kernel/printk

echo "[Unmounting all existing partitions on the device ]"

umount $1* &> /dev/null

echo "[Partitioning $1...]"

DRIVE=$1

cd ../image

filename="fsl-image*.sdcard"
current_filename=`ls | grep fsl-image*.sdcard`

if [ -e $filename ];then
    echo "[Copy $current_filename image]"
    dd if=$current_filename of=$1 &>/dev/null
else
    echo $filename does not exist
    exit 1
fi

echo "[Resize filesystems...]"

rootfs_start=`fdisk -u -l ${DRIVE} | grep ${DRIVE}p2 | awk '{print $2}'`

# Create partition table for extend root file system (/dev/mmcblk1p2) partition
fdisk -u $DRIVE << EOF &>/dev/null
d
2
n
p
2
$rootfs_start

w
EOF

if [ -x /sbin/partprobe ]; then
    /sbin/partprobe ${DRIVE} &> /dev/null
else
    sleep 1
fi

e2fsck -f -y ${DRIVE}p2 &> /dev/null
resize2fs ${DRIVE}p2 &> /dev/null

if [ -x /sbin/partprobe ]; then
    /sbin/partprobe ${DRIVE} &> /dev/null
else
    sleep 1
fi

echo 7 > /proc/sys/kernel/printk
echo "[Done]"

